==> jc-1.4.0.tar.gz: javax/print/attribute/standard/DateTimeAtCreation.h <==
// public final class javax.print.attribute.standard.DateTimeAtCreation

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7f661930fc2aa0c5 javax_print_attribute_DateTimeSyntax
// @dep_class d40ca2eef69bbaaa javax_print_attribute_standard_DateTimeAtCreation

// header file dependencies
// @dep_header javax_print_attribute_DateTimeSyntax

#include "javax/print/attribute/DateTimeSyntax.h"

#ifndef _JC_javax_print_attribute_standard_DateTimeAtCreation_H_
#define _JC_javax_print_attribute_standard_DateTimeAtCreation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Date$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_DateTimeAtCreation$sub_refs	_jc_javax_print_attribute_standard_DateTimeAtCreation$sub_refs;
typedef struct _jc_javax_print_attribute_standard_DateTimeAtCreation$sub_nonrefs	_jc_javax_print_attribute_standard_DateTimeAtCreation$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_DateTimeAtCreation$refs	_jc_javax_print_attribute_standard_DateTimeAtCreation$refs;
typedef struct _jc_javax_print_attribute_standard_DateTimeAtCreation$nonrefs	_jc_javax_print_attribute_standard_DateTimeAtCreation$nonrefs;
typedef struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object	_jc_javax_print_attribute_standard_DateTimeAtCreation$object;

typedef struct _jc_javax_print_attribute_standard_DateTimeAtCreation$fields_struct	_jc_javax_print_attribute_standard_DateTimeAtCreation$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_DateTimeAtCreation$vmethods	_jc_javax_print_attribute_standard_DateTimeAtCreation$vmethods;
typedef const struct _jc_javax_print_attribute_standard_DateTimeAtCreation$vtable	_jc_javax_print_attribute_standard_DateTimeAtCreation$vtable;
typedef const struct _jc_javax_print_attribute_standard_DateTimeAtCreation$vtype	_jc_javax_print_attribute_standard_DateTimeAtCreation$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24DateTimeAtCreation;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_DateTimeAtCreation$fields_struct _jc_javax_print_attribute_standard_DateTimeAtCreation$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_DateTimeAtCreation$method$_init$7de091b6eaf74c19(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *, struct _jc_java_util_Date$object *);

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_DateTimeAtCreation$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_DateTimeAtCreation$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_DateTimeAtCreation$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_DateTimeAtCreation$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_DateTimeAtCreation$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_DateTimeAtCreation$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_DateTimeAtCreation$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_DateTimeSyntax$vmethods	javax_print_attribute_DateTimeSyntax;
	_jc_javax_print_attribute_standard_DateTimeAtCreation$vmethods	javax_print_attribute_standard_DateTimeAtCreation;
};

// Vtype
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_DateTimeAtCreation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$refs {
    _jc_javax_print_attribute_standard_DateTimeAtCreation$sub_refs	javax_print_attribute_standard_DateTimeAtCreation;
    _jc_javax_print_attribute_DateTimeSyntax$sub_refs	javax_print_attribute_DateTimeSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_DateTimeSyntax$sub_nonrefs	javax_print_attribute_DateTimeSyntax;
    _jc_javax_print_attribute_standard_DateTimeAtCreation$sub_nonrefs	javax_print_attribute_standard_DateTimeAtCreation;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object {
	_jc_javax_print_attribute_standard_DateTimeAtCreation$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_DateTimeAtCreation$vtype	*vtype;
	_jc_javax_print_attribute_standard_DateTimeAtCreation$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_DateTimeAtCreation$vtype _jc_javax_print_attribute_standard_DateTimeAtCreation$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_DateTimeAtCreation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_DateTimeAtCreation$class_object;

#endif	/* _JC_javax_print_attribute_standard_DateTimeAtCreation_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/DateTimeAtCreation.h <==
// public final class javax.print.attribute.standard.DateTimeAtCreation

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7f661930fc2aa0c5 javax_print_attribute_DateTimeSyntax
// @dep_class d40ca2eef69bbaaa javax_print_attribute_standard_DateTimeAtCreation

// header file dependencies
// @dep_header javax_print_attribute_DateTimeSyntax

#include "javax/print/attribute/DateTimeSyntax.h"

#ifndef _JC_javax_print_attribute_standard_DateTimeAtCreation_H_
#define _JC_javax_print_attribute_standard_DateTimeAtCreation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Date$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_DateTimeAtCreation$sub_refs	_jc_javax_print_attribute_standard_DateTimeAtCreation$sub_refs;
typedef struct _jc_javax_print_attribute_standard_DateTimeAtCreation$sub_nonrefs	_jc_javax_print_attribute_standard_DateTimeAtCreation$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_DateTimeAtCreation$refs	_jc_javax_print_attribute_standard_DateTimeAtCreation$refs;
typedef struct _jc_javax_print_attribute_standard_DateTimeAtCreation$nonrefs	_jc_javax_print_attribute_standard_DateTimeAtCreation$nonrefs;
typedef struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object	_jc_javax_print_attribute_standard_DateTimeAtCreation$object;

typedef struct _jc_javax_print_attribute_standard_DateTimeAtCreation$fields_struct	_jc_javax_print_attribute_standard_DateTimeAtCreation$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_DateTimeAtCreation$vmethods	_jc_javax_print_attribute_standard_DateTimeAtCreation$vmethods;
typedef const struct _jc_javax_print_attribute_standard_DateTimeAtCreation$vtable	_jc_javax_print_attribute_standard_DateTimeAtCreation$vtable;
typedef const struct _jc_javax_print_attribute_standard_DateTimeAtCreation$vtype	_jc_javax_print_attribute_standard_DateTimeAtCreation$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24DateTimeAtCreation;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_DateTimeAtCreation$fields_struct _jc_javax_print_attribute_standard_DateTimeAtCreation$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_DateTimeAtCreation$method$_init$7de091b6eaf74c19(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *, struct _jc_java_util_Date$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_DateTimeAtCreation$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_DateTimeAtCreation$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_DateTimeAtCreation$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_DateTimeAtCreation$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_DateTimeAtCreation$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_DateTimeAtCreation$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_DateTimeAtCreation$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_DateTimeSyntax$vmethods	javax_print_attribute_DateTimeSyntax;
	_jc_javax_print_attribute_standard_DateTimeAtCreation$vmethods	javax_print_attribute_standard_DateTimeAtCreation;
};

// Vtype
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_DateTimeAtCreation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$refs {
    _jc_javax_print_attribute_standard_DateTimeAtCreation$sub_refs	javax_print_attribute_standard_DateTimeAtCreation;
    _jc_javax_print_attribute_DateTimeSyntax$sub_refs	javax_print_attribute_DateTimeSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_DateTimeSyntax$sub_nonrefs	javax_print_attribute_DateTimeSyntax;
    _jc_javax_print_attribute_standard_DateTimeAtCreation$sub_nonrefs	javax_print_attribute_standard_DateTimeAtCreation;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_DateTimeAtCreation$object {
	_jc_javax_print_attribute_standard_DateTimeAtCreation$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_DateTimeAtCreation$vtype	*vtype;
	_jc_javax_print_attribute_standard_DateTimeAtCreation$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_DateTimeAtCreation$vtype _jc_javax_print_attribute_standard_DateTimeAtCreation$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_DateTimeAtCreation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_DateTimeAtCreation$class_object;

#endif	/* _JC_javax_print_attribute_standard_DateTimeAtCreation_H_ */
